@@ -98,6 +98,13 @@
  */
 #define DUMB    1
 
+/*
+ * Define this if you do not want nmh to attach the local hostname
+ * to local addresses.  You must also define DUMB.  You probably
+ * dont' need this unless you are behind a firewall.
+ */
+/* #define REALLYDUMB  1 */
+
 /*
  * Directs inc/slocal to extract the envelope sender from "From "
  * line.  If inc/slocal is saving message to folder, then this
@@ -118,11 +125,6 @@
  */
 #define MHRC    1
 
-/*
- * Compile in support for MIME.
- */
-#define MIME    1
-
 /*
  * Compile simple ftp client into mhn.  This will be used by mhn
  * for ftp access unless you have specified another access method
