@@ -44,7 +44,7 @@ OfficialName (char *name)
     *q = 0;
     q = site;
 
-    if (uleq (LocalName(), site))
+    if (!strcasecmp (LocalName(), site))
 	return LocalName();
 
 #ifndef	BIND
@@ -57,11 +57,11 @@ OfficialName (char *name)
     }
     if (hosts.h_name || init_hs ())
 	for (h = hosts.h_next; h; h = h->h_next)
-	    if (uleq (h->h_name, q))
+	    if (!strcasecmp (h->h_name, q))
 		return h->h_name;
 	    else
 		for (r = h->h_aliases; *r; r++)
-		    if (uleq (*r, q))
+		    if (!strcasecmp (*r, q))
 			return h->h_name;
 
     strcpy (buffer, site);
