@@ -9,9 +9,6 @@
 #include <h/addrsbr.h>
 #include <zotnet/mf/mf.h>
 
-#undef REALLYDUMB
-
-
 /* High level parsing of addresses:
 
    The routines in zotnet/mf/mf.c parse the syntactic representations of
@@ -73,7 +70,10 @@ static char *note = NULL;
 static char err[BUFSIZ];
 static char adr[BUFSIZ];
 
-char *getusr ();
+/*
+ * external prototypes
+ */
+char *getusername (void);
 
 
 char *
@@ -304,6 +304,10 @@ auxformat (struct mailname *mp, int extras)
 }
 
 
+/*
+ * address specific "sprintf"
+ */
+
 char *
 adrsprintf (char *local, char *domain)
 {
@@ -311,10 +315,10 @@ adrsprintf (char *local, char *domain)
 
     if (local == NULL)
 #ifdef REALLYDUMB
-	return getusr ();
+	return getusername ();
     else
 #endif /* REALLYDUMB */
-	local = getusr ();
+	local = getusername ();
 
     if (domain == NULL)
 #ifdef REALLYDUMB
@@ -364,9 +368,9 @@ ismymbox (struct mailname *np)
      */
     if (am == NULL) {
 	mq.m_next = NULL;
-	mq.m_mbox = getusr ();
+	mq.m_mbox = getusername ();
 	if ((am = context_find ("alternate-mailboxes")) == NULL)
-	    am = getusr();
+	    am = getusername();
 	else {
 	    mp = &mq;
 	    oops = 0;
