@@ -532,11 +532,7 @@ fmt_scan (struct format *format, char *scanl, int width, int *dat)
 	    str = dtwszone (fmt->f_comp->c_tws);
 	    break;
 	case FT_LV_YEAR:
-#ifndef YEARMOD
 	    value = fmt->f_comp->c_tws->tw_year;
-#else /* YEARMOD */
-	    value = (fmt->f_comp->c_tws->tw_year) % 100;
-#endif /* YEARMOD */
 	    break;
 	case FT_LV_WDAY:
 	    if (!(((tws = fmt->f_comp->c_tws)->tw_flags) & (TW_SEXP|TW_SIMP)))
