@@ -131,6 +131,11 @@
    there is data in "name" or "buf").
   */
 
+
+/*
+ * static prototypes
+ */
+static int m_Eom (int, FILE *);
 static unsigned char *matchc(int, char *, int, char *);
 static unsigned char *locc(int, unsigned char *, unsigned char);
 
@@ -599,7 +604,7 @@ m_eomsbr (int (*action)())
  * test for msg delimiter string
  */
 
-int
+static int
 m_Eom (int c, FILE *iob)
 {
     register long pos = 0L;
