@@ -11,7 +11,7 @@
 char *
 m_scratch (char *file, char *template)
 {
-    register char *cp;
+    char *cp;
     static char buffer[BUFSIZ], tmpfil[BUFSIZ];
 
     sprintf (tmpfil, "%sXXXXXX", template);
