@@ -23,7 +23,7 @@ void
 seq_save (struct msgs *mp)
 {
     int i;
-    char flags, *cp, attr[BUFSIZ], seqfile[BUFSIZ * 2];
+    char flags, *cp, attr[BUFSIZ], seqfile[PATH_MAX];
     FILE *fp;
     sigset_t set, oset;
 
@@ -42,43 +42,45 @@ seq_save (struct msgs *mp)
      * is readonly.  This will force all sequences to be private.
      */
     if (mh_seq && *mh_seq != '\0')
-	sprintf (seqfile, "%s/%s", mp->foldpath, mh_seq);
+	snprintf (seqfile, PATH_MAX, "%s/%s", mp->foldpath, mh_seq);
     else
 	set_readonly (mp);
 
     for (i = 0; mp->msgattrs[i]; i++) {
-	sprintf (attr, "atr-%s-%s", mp->msgattrs[i], mp->foldpath);
+	snprintf (attr, BUFSIZ, "atr-%s-%s", mp->msgattrs[i], mp->foldpath);
+
+	/* get space separated list of sequence ranges */
+	if (!(cp = seq_list(mp, mp->msgattrs[i]))) {
+	    context_del (attr);			/* delete sequence from context */
+	    continue;
+	}
+
 	if (is_readonly(mp) || is_seq_private(mp, i)) {
 priv:;
 	    /*
-	     * handle private sequences
+	     * sequence is private
 	     */
-	    if ((cp = seq_list(mp, mp->msgattrs[i])))
-		context_replace (attr, cp);	/* update sequence in context   */
-	    else
-		context_del (attr);	/* delete sequence from context */
+	    context_replace (attr, cp);		/* update sequence in context   */
 	} else {
 	    /*
-	     * handle public sequences
+	     * sequence is public
 	     */
-	    context_del (attr);	/* delete sequence from context */
-
-	    /* get space separated list of sequence ranges */
-	    if (!(cp = seq_list(mp, mp->msgattrs[i])))
-		continue;
+	    context_del (attr);			/* delete sequence from context */
 
 	    if (!fp) {
 		/*
 		 * Attempt to open file for public sequences.
-		 * If that fails (probably because folder is readonly,
-                 * then make sequence private.
+		 * If that fails (probably because folder is
+		 * readonly), then make sequence private.
 		 */
 		if ((fp = fopen (seqfile, "w")) == NULL
-			&& (unlink (seqfile) == NOTOK ||
+			&& (unlink (seqfile) == -1 ||
 			    (fp = fopen (seqfile, "w")) == NULL)) {
 		    admonish (attr, "unable to write");
 		    goto priv;
 		}
+
+		/* block a few signals */
 		sigemptyset (&set);
 		sigaddset(&set, SIGHUP);
 		sigaddset(&set, SIGINT);
