@@ -128,17 +128,17 @@ static char *host = NULL;
 #ifdef	BPOP
 extern char response[];
 
-extern char   *getusr ();
+extern char *getusername (void);
 static char  **getip ();
 #endif	BPOP
 
 RETSIGTYPE sigser(), hupser();
-int	action ();
+int action ();
 
-#ifdef	SIGTSTP
-int	tstpid;
-static  RETSIGTYPE tstpser();
-#endif	SIGTSTP
+#ifdef SIGTSTP
+int tstpid;
+static RETSIGTYPE tstpser();
+#endif /* SIGTSTP */
 
 static char *rcfile=NULL;
 
@@ -1119,8 +1119,8 @@ getbbpop (void)
 	snoop = (cp = getenv ("MHPOPDEBUG")) && *cp;
 	if (rpop) {
 	    if (user == NULL)
-		user = getusr ();
-	    pass = getusr ();
+		user = getusername ();
+	    pass = getusername ();
 	}
 	else
 	    if (strcmp (user, popbbuser) == 0)
