@@ -151,7 +151,7 @@ main(int argc, char **argv)
 
 	    case HELPSW:
 		sprintf(buf, "%s [+folder1 [+folder2 ...]][switches]", invo_name);
-		print_help(buf, switches);
+		print_help(buf, switches, 1);
 		done(1);
 	    case VERSIONSW:
 		print_version(invo_name);
@@ -216,10 +216,10 @@ main(int argc, char **argv)
 
     /*
      * If we didn't specify a sequence, we search
-     * for the `unseen' sequence.
+     * for the "Unseen-Sequence" sequence (if defined).
      */
-    if (!sequence)
-	sequence = context_find(usequence);
+    if (!sequence && !(sequence = context_find(usequence)))
+	adios (NULL, "no default sequence in which to search");
 
     GetFolderOrder();
     ScanFolders();
@@ -384,7 +384,12 @@ BuildFolderListRecurse(char *dirName, struct stat *s, int searchdepth)
 	    strcat(name, "/");
 	strcat(name, dp->d_name);
 	if ((stat(name, &st) != -1) && S_ISDIR(st.st_mode)) {
-	    nlinks--;
+	    /*
+	     * Check if this was really a symbolic link pointing
+	     * to a directory.  If not, then decrement link count.
+	     */
+	    if (lstat (name, &st) == -1)
+		nlinks--;
 	    /* Add this folder to the list */
 	    if (AddFolder(name, showzero) &&
 			(recurse || searchdepth) && st.st_nlink > 2)
