@@ -168,7 +168,7 @@ main (int argc, char **argv)
 
 		case HELPSW: 
 		    sprintf (buf, "%s [+folder] [msg] [switches]", invo_name);
-		    print_help (buf, switches);
+		    print_help (buf, switches, 1);
 		    done (1);
 		case VERSIONSW:
 		    print_version(invo_name);
@@ -460,7 +460,7 @@ static int
 get_folder_info (char *fold, char *msg)
 {
     int	i, retval = 1;
-    register char *mailfile;
+    char *mailfile;
     struct msgs *mp = NULL;
 
     i = total_folders++;
@@ -495,6 +495,7 @@ get_folder_info (char *fold, char *msg)
 		return 0;
 	    }
 
+	    /* set the current message */
 	    if (msg && !sfold (mp, msg))
 		retval = 0;
 
@@ -737,8 +738,13 @@ addir (char *name)
 	    continue;
 	strcpy (cp, dp->d_name);
 	if (stat (name, &st) != -1 && S_ISDIR(st.st_mode)) {
+	    /*
+	     * Check if this was really a symbolic link pointing at
+	     * a directory.  If not, then decrement link count.
+	     */
+	    if (lstat (name, &st) == -1)
+		nlink--;
 	    addfold (base);
-	    nlink--;
 	}
     }
 
