@@ -1,6 +1,6 @@
 
 /*
- * forw.c -- forward message(s)
+ * forw.c -- forward a message, or group of messages.
  *
  * $Id$
  */
@@ -55,16 +55,16 @@ static struct swit switches[] = {
     { "whatnowproc program", 0 },
 #define	NWHATSW               19
     { "nowhatnowproc", 0 },
-#define VERSIONSW             20
+#define	BITSTUFFSW            20
+    { "dashstuffing", 0 },		/* interface to mhl */
+#define	NBITSTUFFSW           21
+    { "nodashstuffing", 0 },
+#define VERSIONSW             22
     { "version", 0 },
-#define	HELPSW                21
+#define	HELPSW                23
     { "help", 4 },
-#define	FILESW                22
+#define	FILESW                24
     { "file file", -4 },		/* interface from msh */
-#define	DASHSW                23
-    { "dashmunging", -4 },		/* interface to mhl */
-#define	NDASHSW               24
-    { "nodashmunging", -6 },
 
 #ifdef MHE
 #define	BILDSW                25
@@ -110,7 +110,7 @@ static struct msgs *mp = NULL;		/* used a lot */
  * static prototypes
  */
 static void mhl_draft (int, char *, int, int, char *, char *, int);
-static void copy_draft (int, char *, char *, int, int);
+static void copy_draft (int, char *, char *, int, int, int);
 static void copy_mime_draft (int);
 static int build_form (char *, char *, int, int);
 
@@ -119,7 +119,7 @@ int
 main (int argc, char **argv)
 {
     int msgp = 0, anot = 0, inplace = 1, mime = 0;
-    int issue = 0, volume = 0, dashflg = 1;
+    int issue = 0, volume = 0, dashstuff = 0;
     int nedit = 0, nwhat = 0, i, in;
     int out, isdf = 0, msgnum;
     char *cp, *cwd, *maildir, *dfolder = NULL;
@@ -269,11 +269,11 @@ main (int argc, char **argv)
 		    isdf = NOTOK;
 		    continue;
 
-		case DASHSW: 
-		    dashflg++;
+		case BITSTUFFSW: 
+		    dashstuff = 1;	/* trinary logic */
 		    continue;
-		case NDASHSW: 
-		    dashflg = 0;
+		case NBITSTUFFSW: 
+		    dashstuff = -1;	/* trinary logic */
 		    continue;
 	    }
 	}
@@ -418,11 +418,11 @@ try_it_again: ;
 	 * messages into the draft using mhlproc.
 	 */
 	if (filter)
-	    mhl_draft (out, digest, volume, issue, drft, filter, dashflg);
+	    mhl_draft (out, digest, volume, issue, drft, filter, dashstuff);
 	else if (mime)
 	    copy_mime_draft (out);
 	else
-	    copy_draft (out, digest, drft, volume, issue);
+	    copy_draft (out, digest, drft, volume, issue, dashstuff);
 	close (out);
 
 	if (digest) {
@@ -456,7 +456,7 @@ try_it_again: ;
 
 static void
 mhl_draft (int out, char *digest, int volume, int issue,
-            char *file, char *filter, int dashflg)
+            char *file, char *filter, int dashstuff)
 {
     pid_t child_id;
     int i, msgnum, pd[2];
@@ -484,6 +484,7 @@ mhl_draft (int out, char *digest, int volume, int issue,
 	    vec[i++] = "-forwall";
 	    vec[i++] = "-form";
 	    vec[i++] = filter;
+
 	    if (digest) {
 		vec[i++] = "-digest";
 		vec[i++] = digest;
@@ -492,7 +493,17 @@ mhl_draft (int out, char *digest, int volume, int issue,
 		vec[i++] = "-volume";
 		sprintf(buf2, "%d", volume); vec[i++] = buf2;
 	    }
-	    vec[i++] = dashflg ? "-dashmunging" : "-nodashmunging";
+
+	    /*
+	     * Are we dashstuffing (quoting) the lines that begin
+	     * with `-'.  We use the mhl default (don't add any flag)
+	     * unless the user has specified a specific flag.
+	     */
+	    if (dashstuff > 0)
+		vec[i++] = "-dashstuffing";
+	    else if (dashstuff < 0)
+		vec[i++] = "-nodashstuffing";
+
 	    if (mp->numsel >= MAXARGS - i)
 		adios (NULL, "more than %d messages for %s exec",
 			vec[0], MAXARGS - i);
@@ -518,11 +529,12 @@ mhl_draft (int out, char *digest, int volume, int issue,
 
 /*
  * Copy the messages into the draft.  The messages are
- * bit-stuffed, but not filtered through the mhlproc.
+ * not filtered through the mhlproc.  Do dashstuffing if
+ * necessary.
  */
 
 static void
-copy_draft (int out, char *digest, char *file, int volume, int issue)
+copy_draft (int out, char *digest, char *file, int volume, int issue, int dashstuff)
 {
     int fd,i, msgcnt, msgnum;
     register char *bp, *msgnam;
@@ -548,18 +560,27 @@ copy_draft (int out, char *digest, char *file, int volume, int issue)
 		admonish (msgnam, "unable to read message");
 		continue;
 	    }
-	    cpydgst (fd, out, msgnam, file);
-	    close (fd);
 
+	    /*
+	     * Copy the message.  Add RFC934 quoting (dashstuffing)
+	     * unless given the -nodashstuffing flag.
+	     */
+	    if (dashstuff >= 0)
+		cpydgst (fd, out, msgnam, file);
+	    else
+		cpydata (fd, out, msgnam, file);
+
+	    close (fd);
 	    msgcnt++;
 	}
     }
 
-    if (digest)
+    if (digest) {
 	strcpy (buffer, delim4);
-    else
+    } else {
 	sprintf (buffer, "\n------- End of Forwarded Message%s\n\n",
 		mp->numsel > 1 ? "s" : "");
+    }
     write (out, buffer, strlen (buffer));
 
     if (digest) {
