@@ -88,31 +88,35 @@ static struct swit switches[] = {
     { "version", 0 },
 #define	HELPSW                   21
     { "help", 4 },
-#define	MAILSW                   22
+#define BITSTUFFSW               22
+    { "dashstuffing", -12 },		/* should we dashstuff BCC messages? */
+#define NBITSTUFFSW              23
+    { "nodashstuffing", -14 },
+#define	MAILSW                   24
     { "mail", -4 },			/* specify MAIL smtp mode */
-#define	SAMLSW                   23
+#define	SAMLSW                   25
     { "saml", -4 },			/* specify SAML smtp mode */
-#define	SENDSW                   24
+#define	SENDSW                   26
     { "send", -4 },			/* specify SEND smtp mode */
-#define	SOMLSW                   25
+#define	SOMLSW                   27
     { "soml", -4 },			/* specify SOML smtp mode */
-#define	ANNOSW                   26
+#define	ANNOSW                   28
     { "idanno number", -6 },		/* interface from send    */
-#define	DLVRSW                   27
+#define	DLVRSW                   29
     { "deliver address-list", -7 },
-#define	CLIESW                   28
+#define	CLIESW                   30
     { "client host", -6 },
-#define	SERVSW                   29
+#define	SERVSW                   31
     { "server host", -6 },		/* specify alternate SMTP server */
-#define	SNOOPSW                  30
+#define	SNOOPSW                  32
     { "snoop", -5 },			/* snoop the SMTP transaction */
-#define	FILLSW                   31
+#define	FILLSW                   33
     { "fill-in file", -7 },
-#define	FILLUSW                  32
+#define	FILLUSW                  34
     { "fill-up", -7 },
-#define	PARTSW                   33
+#define	PARTSW                   35
     { "partno", -6 },
-#define	QUEUESW                  34
+#define	QUEUESW                  36
     { "queued", -6 },
     { NULL, 0 }
 };
@@ -275,7 +279,7 @@ static void pl (void);
 static void anno (void);
 static int annoaux (struct mailname *);
 static void insert_fcc (struct headers *, char *);
-static void make_bcc_file (void);
+static void make_bcc_file (int);
 static void verify_all_addresses (int);
 static void chkadr (void);
 static void sigon (void);
@@ -293,7 +297,7 @@ static int find_prefix (void);
 int
 main (int argc, char **argv)
 {
-    int state, compnum;
+    int state, compnum, dashstuff = 0;
     char *cp, *msg = NULL, **argp = argv + 1;
     char buf[BUFSIZ], name[NAMESZ];
     FILE *in, *out;
@@ -377,6 +381,13 @@ main (int argc, char **argv)
 		    format = 0;
 		    continue;
 
+		case BITSTUFFSW:
+		    dashstuff = 1;
+		    continue;
+		case NBITSTUFFSW:
+		    dashstuff = -1;
+		    continue;
+
 		case MIMESW:
 		    mime++;
 		    filter = NULL;
@@ -601,7 +612,7 @@ main (int argc, char **argv)
 #endif /* MMDFMTS */
 
     if (msgflags & MINV) {
-	make_bcc_file ();
+	make_bcc_file (dashstuff);
 	if (msgflags & MVIS) {
 	    verify_all_addresses (verbose);
 	    post (tmpfil, 0, verbose);
@@ -811,6 +822,12 @@ start_headers (void)
 }
 
 
+/*
+ * Now that we've outputted the header fields in the draft
+ * message, we will now output any remaining header fields
+ * that we need to add/create.
+ */
+
 static void
 finish_headers (FILE *out)
 {
@@ -1079,7 +1096,7 @@ insert_fcc (struct headers *hdr, char *pp)
  */
 
 static void
-make_bcc_file (void)
+make_bcc_file (int dashstuff)
 {
     int fd, i;
     pid_t child_id;
@@ -1106,9 +1123,15 @@ make_bcc_file (void)
     if (mime) {
 	char *cp;
 
+	/*
+	 * Check if any lines in the message clash with the
+	 * prefix for the MIME multipart separator.  If there
+	 * is a clash, increment one of the letters in the
+	 * prefix and check again.
+	 */
 	if ((cp = strchr(prefix, 'a')) == NULL)
 	    adios (NULL, "lost prefix start");
-	while (find_prefix () == NOTOK)
+	while (find_prefix () == NOTOK) {
 	    if (*cp < 'z')
 		(*cp)++;
 	    else
@@ -1116,6 +1139,7 @@ make_bcc_file (void)
 		    adios (NULL, "can't find a unique delimiter string");
 		else
 		    (*cp)++;
+	}
 
 	fprintf (out, "%s: %s\n%s: multipart/digest; boundary=\"",
 		 VRSN_FIELD, VRSN_VALUE, TYPE_FIELD);
@@ -1147,6 +1171,12 @@ make_bcc_file (void)
 		vec[i++] = "-form";
 		vec[i++] = filter;
 		vec[i++] = tmpfil;
+
+		/* was the flag -[no]dashstuffing specified? */
+		if (dashstuff > 0)
+		    vec[i++] = "-dashstuffing";
+		else if (dashstuff < 0)
+		    vec[i++] = "-nodashstuffing";
 		vec[i] = NULL;
 
 		execvp (mhlproc, vec);
@@ -1161,7 +1191,13 @@ make_bcc_file (void)
     } else {
 	if ((fd = open (tmpfil, O_RDONLY)) == NOTOK)
 	    adios (tmpfil, "unable to re-open");
-	if (mime)
+
+	/*
+	 * If using MIME encapsulation, or if the -nodashstuffing
+	 * flag was given, then just copy message.  Else do
+	 * RFC934 quoting (dashstuffing).
+	 */
+	if (mime || dashstuff < 0)
 	    cpydata (fd, fileno (out), tmpfil, bccfil);
 	else
 	    cpydgst (fd, fileno (out), tmpfil, bccfil);
@@ -1177,6 +1213,11 @@ make_bcc_file (void)
 }
 
 
+/*
+ * Scan message to check if any lines clash with
+ * the prefix of the MIME multipart separator.
+ */
+
 static int
 find_prefix (void)
 {
@@ -1205,7 +1246,6 @@ find_prefix (void)
 	}
 
     fclose (in);
-	
     return result;
 }
 
