@@ -195,7 +195,7 @@ scan (FILE *inb, int innum, int outnum, char *nfs, int width, int curflg,
 		 */
 		if ((cptr = wantcomp[CHASH(name)])) {
 		    do {
-			if (uleq(name, cptr->c_name)) {
+			if (!strcasecmp(name, cptr->c_name)) {
 			    if (! cptr->c_text) {
 				cptr->c_text = tmpbuf;
 				for (cp = tmpbuf + strlen (tmpbuf) - 1; 
