@@ -68,19 +68,23 @@ static struct swit switches[] = {
     { "version", 0 },
 #define	HELPSW                27
     { "help", 4 },
-#define	MAILSW                28
+#define BITSTUFFSW            28
+    { "dashstuffing", -12 },
+#define NBITSTUFFSW           29
+    { "nodashstuffing", -14 },
+#define	MAILSW                30
     { "mail", -4 },
-#define	SAMLSW                29
+#define	SAMLSW                31
     { "saml", -4 },
-#define	SENDSW                30
+#define	SENDSW                32
     { "send", -4 },
-#define	SOMLSW                31
+#define	SOMLSW                33
     { "soml", -4 },
-#define	CLIESW                32
+#define	CLIESW                34
     { "client host", -6 },
-#define	SERVSW                33
+#define	SERVSW                35
     { "server host", -6 },
-#define	SNOOPSW               34
+#define	SNOOPSW               36
     { "snoop", -5 },
     { NULL, 0 }
 };
@@ -228,6 +232,8 @@ main (int argc, char **argv)
 		case NFILTSW: 
 		case FRMTSW: 
 		case NFRMTSW: 
+		case BITSTUFFSW:
+		case NBITSTUFFSW:
 		case MSGDSW: 
 		case NMSGDSW: 
 		case WATCSW: 
