@@ -27,6 +27,13 @@ char *distfile = NULL;
 static int armed = 0;
 static jmp_buf env;
 
+/*
+ * external prototypes
+ */
+int sendsbr (char **, int, char *, struct stat *);
+void done (int);
+char *getusername (void);
+
 /*
  * static prototypes
  */
@@ -37,13 +44,6 @@ static void annoaux (int);
 static int splitmsg (char **, int, char *, struct stat *);
 static int sendaux (char **, int, char *, struct stat *);
 
-/*
- * prototypes
- */
-int sendsbr (char **, int, char *, struct stat *);
-void done (int);
-char *getusr();
-
 
 /*
  * Entry point into (back-end) routines to send message.
@@ -430,7 +430,7 @@ alert (char *file, int out)
 	    sprintf (buf, "send failed on %s",
 			forwsw ? "enclosed draft" : file);
 
-	    execlp (mailproc, r1bindex (mailproc, '/'), getusr (),
+	    execlp (mailproc, r1bindex (mailproc, '/'), getusername (),
 		    "-subject", buf, NULL);
 	    fprintf (stderr, "unable to exec ");
 	    perror (mailproc);
