@@ -273,7 +273,7 @@ main (int argc, char **argv)
     }
 
     if (addr == NULL)
-	addr = getusr ();
+	addr = getusername ();
     if (user == NULL)
 	user = (cp = strchr(addr, '.')) ? ++cp : addr;
     if ((pw = getpwnam (user)) == NULL)
