@@ -170,7 +170,11 @@ static FILE *out;		/* output (temp) file */
 
 extern char *sendmail;
 
-extern char *getfullname (), *getusr ();
+/*
+ * external prototypes
+ */
+extern char *getfullname (void);
+extern char *getusername (void);
 
 /*
  * static prototypes
@@ -524,7 +528,7 @@ start_headers (void)
     char *cp;
     char sigbuf[BUFSIZ];
 
-    strcpy( from, getusr() );
+    strcpy( from, getusername() );
 
     if ((cp = getfullname ()) && *cp) {
 	strcpy (sigbuf, cp);
