@@ -641,25 +641,29 @@ static struct swit  sendswitches[] = {
     { "version", 0 },
 #define	SHELPSW          23
     { "help", 4 },
-#define	MAILSW           24
+#define BITSTUFFSW       24
+    { "dashstuffing", -12 },
+#define NBITSTUFFSW      25
+    { "nodashstuffing", -14 },
+#define	MAILSW           26
     { "mail", -4 },
-#define	SAMLSW           25
+#define	SAMLSW           27
     { "saml", -4 },
-#define	SSNDSW           26
+#define	SSNDSW           28
     { "send", -4 },
-#define	SOMLSW           27
+#define	SOMLSW           29
     { "soml", -4 },
-#define	CLIESW           28
+#define	CLIESW           30
     { "client host", -6 },
-#define	SERVSW           29
+#define	SERVSW           31
     { "server host", -6 },
-#define	SNOOPSW          30
+#define	SNOOPSW          32
     { "snoop", -5 },
-#define SDRFSW           31
+#define SDRFSW           33
     { "draftfolder +folder", -6 },
-#define SDRMSW           32
+#define SDRMSW           34
     { "draftmessage msg", -6 },
-#define SNDRFSW          33
+#define SNDRFSW          35
     { "nodraftfolder", -3 },
     { NULL, 0 }
 };
@@ -776,6 +780,8 @@ sendit (char *sp, char **arg, char *file, int pushed)
 		case NFILTSW: 
 		case FRMTSW: 
 		case NFRMTSW: 
+		case BITSTUFFSW:
+		case NBITSTUFFSW:
 		case MIMESW: 
 		case NMIMESW: 
 		case MSGDSW: 
